
# (f) Frequency of co-occurrence and body size comparisons

# Uses 2017 Beetle Survey Data - testing if orbicollis or sayi is the larger beetle in the traps,
# and how frequently the two species co-occur across seasons.

#load dataset (f_field_survey_data.csv)
dat <- read.csv(file.choose())
names(dat)

# aggregate dataset, calculating max_size and count for each species in each trap on each day
is.numeric(dat$mass)
dat$site <- as.factor(dat$site)
is.numeric(dat$date)
dat$species <- as.factor(dat$species)

dat1 <- (aggregate(mass ~ site + date + species, data = dat, FUN = function(x) c(max_size = max(x), number = length(x))))
head(dat1)
tail(dat1)
agg_df <- do.call(data.frame, dat1)
head(agg_df)
tail(agg_df)

# melt dataset using reshape2 package
# change data into long format so that we have a species column for the analysis
library(reshape2)
library(data.table)
dat2 <- dcast(setDT(agg_df), site + date ~ species, value.var = c("mass.max_size", "mass.number"))
head(dat2)
tail(dat2)

#######################################################################################
# When sayi occurs with orbicollis, is the largest orbicollis larger than the largest sayi?

dat3 <- subset(dat2, dat2$mass.max_size_N_sayi > 0)
dat4 <- subset(dat3, dat3$mass.max_size_N_orbicollis > 0)
dat4$diff.size <- log(dat4$mass.max_size_N_orbicollis / dat4$mass.max_size_N_sayi)

# look at general relationships for species - nonlinear?
library(ggplot2)
theme_bw.2<-theme_bw() + theme(legend.direction="horizontal", legend.position=c(0.5,1.047), legend.title=element_blank())

rel.size.date <- ggplot(dat4, aes(x=date, y=diff.size)) +
  ggtitle("Relative size of largest N. orbicollis and largest N. sayi caught in the same trap") +
  xlab("Calendar date") +
  ylab("Relative size of largest orbicollis to largest sayi") +
  ylim(-1.5, 1.5) +
  geom_point(shape=1) +     
  geom_abline(intercept = 0, slope = 0, linetype = "solid") +
  geom_smooth(method="loess",span=1.5, size=1.5, linetype="solid") 
rel.size.date + theme_bw.2

hist(dat4$diff.size)
hist(dat4$date)

# initial attempts to model with quadratic date predictor and glm/gls did not fit well
# moved to gam models to better model nonlinear relationship

library(mgcv)
library(MASS)
library(dplyr)
library(readr)

ma <- gam(diff.size ~ s(date, k = 20), method = "REML", data = dat4)
gam.check(ma)
plot(fitted(ma)^.5, residuals(ma))
plot(ma, shade = TRUE, pages = 1)
summary(ma)

mpred <- predict(ma, se.fit = TRUE)
mpred$lci <- mpred$fit - 1.983972*mpred$se.fit #lower 95%CL
mpred$uci <- mpred$fit + 1.983972*mpred$se.fit #upper 95%CL
dataf <- data.frame(dat4,mpred)

# create groups in case we want to use colour
dataf$largest.spp[dataf$"diff.size">0] <- "orbicollis.larger" 
dataf$largest.spp[dataf$"diff.size"<=0] <- "sayi.larger" 
dataf$largest.spp <- as.factor(dataf$largest.spp)

a.pred <- ggplot(dataf, aes(x=date, y=diff.size)) +
  ggtitle("Relative size of largest N. orbicollis and largest N. sayi caught in the same trap") +
  xlab("Calendar date") +
  ylab("Relative size of largest orbicollis to largest sayi") +
  coord_cartesian(ylim=c(-1.5,1.5)) + 
  geom_ribbon(aes(ymin=lci,ymax=uci),fill="gray80",colour=NA) +
  geom_line(aes(y=fit)) +
  geom_point(shape = 1, size = 3) +
  geom_abline(intercept = 0, slope = 0, linetype = "solid")
a.pred + theme_bw.2 # model results and raw data; export 5 x 6; figure 4b


#######################################################################################
# When sayi occurs with orbicollis, are the average sizes different?

dat.ave1 <- (aggregate(mass ~ site + date + species, data = dat, FUN = function(x) c(mean_size = mean(x), number = length(x))))
head(dat.ave1)
tail(dat.ave1)
agg_mn_df <- do.call(data.frame, dat.ave1)
head(agg_mn_df)
tail(agg_mn_df)

# melt dataset using reshape2 package
# change data into long format so that we have a species column for the analysis
library(reshape2)
library(data.table)
dat.ave2 <- dcast(setDT(agg_mn_df), site + date ~ species, value.var = c("mass.mean_size", "mass.number"))
head(dat.ave2)
tail(dat.ave2)

dat.ave3 <- subset(dat.ave2, dat.ave2$mass.mean_size_N_sayi > 0)
dat.ave4 <- subset(dat.ave3, dat.ave3$mass.mean_size_N_orbicollis > 0)
dat.ave4$diff.ave.size <- log(dat.ave4$mass.mean_size_N_orbicollis / dat.ave4$mass.mean_size_N_sayi)

# look at general relationships for species - nonlinear?
rel.mn.size.date <- ggplot(dat.ave4, aes(x=date, y=diff.ave.size)) +
  ggtitle("Relative size of largest N. orbicollis and largest N. sayi caught in the same trap") +
  xlab("Calendar date") +
  ylab("Relative size of largest orbicollis to largest sayi") +
  ylim(-1.5, 1.5) +
  geom_point(shape=1) +     
  geom_abline(intercept = 0, slope = 0, linetype = "solid") +
  geom_smooth(method="loess",span=1.5, size=1.5, linetype="solid") 
rel.mn.size.date + theme_bw.2 # 

hist(dat.ave4$diff.ave.size)

# again, initial attempts to model with quadratic date predictor and glm/gls did not fit well
# moved to gam models to better model nonlinear relationship

library(mgcv)
library(MASS)
library(dplyr)
library(readr)

ma2 <- gam(diff.ave.size ~ s(date, k = 20), method = "REML", data = dat.ave4)
gam.check(ma2)
plot(fitted(ma2)^.5, residuals(ma2))
plot(ma2, shade = TRUE, pages = 1)
summary(ma2)

mpred2 <- predict(ma2, se.fit = TRUE)
mpred2$lci <- mpred2$fit - 1.983972*mpred2$se.fit #lower 95%CL
mpred2$uci <- mpred2$fit + 1.983972*mpred2$se.fit #upper 95%CL
dataf2 <- data.frame(dat.ave4,mpred2)

# create groups in case we want to use colour
dataf2$largest.ave.spp[dataf2$"diff.ave.size">0] <- "orbicollis.larger" 
dataf2$largest.ave.spp[dataf2$"diff.ave.size"<=0] <- "sayi.larger" 
dataf2$largest.ave.spp <- as.factor(dataf2$largest.ave.spp)

a.pred2 <- ggplot(dataf2, aes(x=date, y=diff.ave.size)) +
  ggtitle("Relative size of mean N. orbicollis and mean N. sayi caught in the same trap") +
  xlab("Calendar date") +
  ylab("Relative size of largest orbicollis to largest sayi") +
  coord_cartesian(ylim=c(-1.5,1.5)) + 
  geom_ribbon(aes(ymin=lci,ymax=uci),fill="gray80",colour=NA) +
  geom_line(aes(y=fit)) +
  geom_point(shape = 1, size = 3) +
  geom_abline(intercept = 0, slope = 0, linetype = "solid")
a.pred2 + theme_bw.2 # model results and raw data; export 5 x 6; figure 4c


#######################################################################################
# What proportion of sayi occurs with orbicollis?

names(dat3)
plot(dat3$mass.number_N_orbicollis ~ dat3$date)
plot(dat3$mass.number_N_sayi ~ dat3$date)
plot(dat3$mass.number_N_sayi ~ dat3$mass.number_N_orbicollis)

dat3$orb.present[dat3$mass.number_N_orbicollis > 0] <- 1 
dat3$orb.present[is.na(dat3$mass.number_N_orbicollis)] <- 0 
dat3$sayi.present[dat3$mass.number_N_sayi > 0] <- 1 
dat3$sayi.present[is.na(dat3$mass.number_N_sayi)] <- 0 

library(plyr)
dat5 <- (aggregate(cbind(orb.present, sayi.present) ~ date, data = dat3, FUN = sum))
head(dat5)
dat5$prop.orb <- (dat5$orb.present / dat5$sayi.present)

sayi.with.orb <- ggplot(dat5, aes(x=date, y=prop.orb)) +
  ggtitle("Proportion of traps with N. sayi that also caught N. orbicollis") +
  xlab("Calendar date") +
  ylab("Proportion of traps with N. sayi that also caught N. orbicollis") +
  ylim(-0.12, 1.12) +
  geom_point(shape=1, size=3) +     
  geom_abline(intercept = 0, slope = 0, linetype = "dotted") +
  geom_abline(intercept = 1, slope = 0, linetype = "dotted")
  #geom_smooth(method="loess",span=1.5, size=1.5, linetype="solid") 
sayi.with.orb + theme_bw.2 # Figure 4a

# combine presence/absence of orbicollis with sayi
dat5$orb.pres <- cbind(dat5$orb.present, (dat5$sayi.present-dat5$orb.present))

ma3 <- gam(orb.pres ~ s(date, k = 20), method = "REML", data = dat5, family = binomial)
gam.check(ma3)
plot(fitted(ma3)^.5, residuals(ma3))
plot(ma3, shade = TRUE, pages = 1)
summary(ma3)

mpred.4 <- predict(ma3, se.fit = TRUE)
linkinv <- family(ma3)$linkinv ## inverse-link function
dataf4 <- data.frame(dat5, mpred.4)
dataf4$pred1 <- linkinv(dataf4$fit)
alpha <- 0.95
sc <- abs(qnorm((1-alpha)/2))  ## Normal approx. to likelihood
dataf4 <- transform(dataf4,
                     lwr1=linkinv(fit-sc*dataf4$se.fit),
                     upr1=linkinv(fit+sc*dataf4$se.fit))

a.pred3 <- ggplot(dataf4, aes(x=date, y=prop.orb)) +
  ggtitle("Proportion of traps with N. sayi that also caught N. orbicollis") +
  xlab("Calendar date") +
  ylab("Proportion of traps with N. sayi that also caught N. orbicollis") +
  coord_cartesian(ylim=c(0,1)) + 
  geom_ribbon(aes(ymin=lwr1,ymax=upr1),fill="gray80",colour=NA) +
  geom_line(aes(y=pred1)) +
  geom_point(shape = 1, size = 3) +
  geom_abline(intercept = 0, slope = 0, linetype = "solid") +
  geom_abline(intercept = 1, slope = 0, linetype = "solid") +
  geom_abline(intercept = 0.5, slope = 0, linetype = "dotted")
a.pred3 + theme_bw.2 # model results and raw data; figure 4a


#####################################################################
